#' d from 2 x 2 factorial ANOVA given means, standard deviations and sample sizes
#'
#'The means, standard deviations and sample sizes are used to compute the effect size.  
#'@param m1     Mean for group 1
#'@param m2     Mean for group 2
#'@param m3     Mean for group 3
#'@param m4     Mean for group 4
#'@param sd1    Standard deviation for group 1
#'@param sd2    Standard deviation for group 2
#'@param sd3    Standard deviation for group 3
#'@param sd4    Standard deviation for group 4
#'@param n1     Sample size for group 1
#'@param n2     Sample size for group 2
#'@param n3     Sample size for group 3
#'@param n4     Sample size for group 4
#'@return Effect size (d) 
#'@return Variance for the effect size (Var)
#'@examples
#'ESsdm_factorial(7.21, 8.99, 7.59, 8.89, 1.85, 2.44, 1.39, 2.16, 72, 96, 63, 69)
#'@export
ESsdm_factorial<-function(m1, m2, m3, m4, sd1, sd2, sd3, sd4, n1, n2, n3, n4)
{
  N1 <- (n1+ n3)
  N2 <- (n2 + n4) 
  Mean_0 <- (1/N1)*((m1*n1)+(m3*n3))
  Mean_1 <- (1/N2)*((m2*n2)+(m4*n4))
  GM0 <- (m1+m3)/2
  GM1 <-(m2+m4)/2
  Std_0 <- (((n1-1)*(sd1^2)) + ((n3-1)*(sd3^2)) + (n1*((m1-GM0)^2)) + (n3*(m3-GM0)^2))/(N1-1)
  Std_1 <- (((n2-1)*(sd2^2)) + ((n4-1)*(sd4^2)) + (n2*((m2-GM1)^2)) + (n4*(m4-GM1)^2))/(N2-1)
  Sp <- sqrt((((n1+n3)-1)*Std_0) + (((n2+n4)-1)*Std_1))/((N1+N2)-2)
  Sp <- sqrt ((((N1-1)*Std_0) + ((N2-1)*Std_1))/(N1+N2-2))
  MeanD <-Mean_1 - Mean_0
  ES <- MeanD/Sp
  Var <-((N1+N2)/(N1*N2) + ((ES^2)/(2*(N1+N2)))) 
  return (setNames((list(ES, Var)),c("Effect Size", "Variance")))
}

#' d from 2 x 2 factorial ANOVA given means, sum of squares and degrees of freedom
#'
#'Using Glass's procedure, the sum of squares and degrees of freedom are used to estimate the pooled standard deviation. Then, the means and pooled standard deviations are used to compute the effect size. In this example, the effect size for factor A is computed.  
#'@param m1     Mean for group 1
#'@param m2     Mean for group 2
#'@param n1     Sample size for group 1
#'@param n2     Sample size for group 2
#'@param SSb    Sum of squares for factor b
#'@param SSab   Sum of squares for interaction between a & b
#'@param SSw    Sum of squares for within
#'@param dfb    Degrees of freedom for b
#'@param dfab   Degrees of freedom for ab
#'@param dfw    Degrees of freedom for within
#'@return Effect size (d) 
#'@return Variance for the effect size (Var)
#'@examples
#'ESsmd_factorialG(7.21, 8.99, 72, 96, 1.04, 4.35, 1242.46, 1, 1, 296)
#'@export
ESsmd_factorialG <-function(m1, m2, n1, n2, SSb, SSab, SSw, dfb, dfab, dfw)
{
  MeanD <-m2-m1
  Sp <- sqrt((SSb+SSab+SSw)/(dfb+dfab+dfw))
  ES <-MeanD/Sp
  Var<-((n1+n2)/(n1*n2) + ((ES^2)/(2*(n1+n2)))) 
  return (setNames((list(ES, Var)),c("Effect Size", "Variance")))
}

#' d from 2 x 2 factorial ANOVA given sample sizes, degrees of freedom and F-values
#'
#'The sample sizes, degrees of freedom and F-values are used to compute the effect size. In this example, the effect size for factor A is computed.  
#'@param na1     Sample size for group 1 for factor A
#'@param na2     Sample size for group 2 for factor A
#'@param nb1     Sample size for group 1 for factor B
#'@param nb2     Sample size for group 2 for factor B
#'@param dfb     Degrees of freedom for b
#'@param dfab    Degrees of freedom for ab
#'@param dfw     Degrees of freedom for within
#'@param Fa      F-value for factor A
#'@param Fb      F-value for factor B
#'@param Fab     F-value for interaction factor AB
#'@return Effect size (d) 
#'@return Variance for the effect size (Var)
#'@examples
#'ESsmd_factorialF (72, 96, 63, 69, 1, 1, 296, 43.3, .25, 1.04)
#'@export
ESsmd_factorialF<- function (na1, na2, nb1, nb2, dfb, dfab, dfw, Fa, Fb, Fab)
{  
  nlevel1_a <-na1 + na2
  nlevel2_a <-nb1 + nb2
  ga <- sqrt(Fa*((nlevel1_a +nlevel2_a)/(nlevel1_a*nlevel2_a)))
  ES <-ga* (sqrt((dfb + dfab + dfw)/((dfb*Fb)+(dfab*Fab)+dfw)))
  Var <- ((na1+na2)/(na1*na2) + ((ES^2)/(2*(na1+na2))))
  return (setNames((list(ES, Var)),c("Effect Size", "Variance")))
}
